PrivWriteConfig

Enum PrivWriteConfig 

pub enum PrivWriteConfig {
    Invalid,
    Encrypt,
}

Variants



Invalid

PrivWrite will return an error if the target key slot has this value.



Encrypt

Writes to this slot require a properly computed MAC and the inputdata must be encrypted by the system with SlotConfig.WriteKey using the encryption algorithm documented with PrivWrite.